@@ -10,7 +10,7 @@ RESULT_URL = 'https://informationtracer.com/api/v1/result'
 JOB_STATUS_URL = 'https://informationtracer.com/job_status'
 
 def trace(query=None, skip_result=False, result_filename=None, 
-    timeout=240, verbose=True, dataset='API_submit', 
+    timeout=240, verbose=True, label='API_submit', 
     token=None, start_date=None, end_date=None):
     """
         Submit a query, wait for the job to finish, and collect the results
@@ -37,7 +37,7 @@ def trace(query=None, skip_result=False, result_filename=None,
                                    'token': token,
                                    'start_date': start_date,
                                    'end_date': end_date,
-                                   'dataset': dataset,
+                                   'label': label,
                                    }                                   
                                    )
     
